LiveLib (Живая библиотека) — социальная сеть читателей книг
Description: Читайте рецензии и отзывы на книги, изучайте интересные подборки книг, выписывайте цитаты из книг, делитесь впечатлениями о книгах

Войти или зарегистрироваться

# Что почитать

LiveLib.ru — самая большая в рунете коллекция рецензий. У нас можно создать тематическую подборку книг, составить биографию любимого писателя, получить рекомендацию, почитать отзывы о книгах, узнать рейтинг лучших книг года или месяца по мнению самих читателей.

# Дневник читателя онлайн

LiveLib.ru — ваша личная библиотека. С нашей помощью вы всегда сможете вспомнить, что читали в прошлом году, какие цитаты понравились вам больше всего, поведать миру собственное мнение в формате отзыва, рецензии или блога.

# Сообщество читателей книг

LiveLib.ru — сервис для общения. Здесь можно найти единомышленников, которым нравятся ваши любимые книги; узнать, какие новинки сегодня на слуху; обсудить классику, которая никогда не выходит из моды; пообщаться на любые темы на книжном форуме.

### Вы можете зайти на Лайвлиб, используя свой аккаунт в других социальных сетях:

Deli позавчера 06:53

### В данный момент проходят игры

Deli 1 декабря 2014 г.

### Новогодний конкурс сказок

zhem4uzhinka 6 декабря 2014 г.

### Долгая прогулка 2015. Флудилка. Идет формирование команд

# Рецензия на книгу «И пели птицы...»

cadgoddo 30 ноября 2014 г., 18:08

К столетию начала Первой Мировой войны в Великобритании и США относительно большим тиражом переиздали роман Себастьяна Фолкса "И пели птицы...", а у нас его перевели и издали в первый раз. Большой поклон издательству "Синдбад", всего лишь во второй раз после "Золота" Криса Клива обратившихся к литературе Великобритании, и на этот раз попавших в самую точку. Этот роман - то, чего действительно не хватало на русском языке. Сказанное не означает, что "И пели птицы..." - шедевр, нареканий у меня много, но, похоже, они имеют личный характер.

Переводчик - Сергей Ю. (Б.?) Ильин - имеет на счету такие работы, как "Подснежники" Эндрю Д. Миллера, "Плоть и кровь" Майкла Каннингема, "Осень в Петербурге" Джозефа М. Кутзее. "Гиппопотам" Стивена Фрая. Существует некоторая путаница - статья в русской Википедии о Сергее Борисовиче Ильине (1948-, Саратов) упоминает практически тех же авторов. Отчество "Ю." - с Литмира. Надеюсь, это просто ошибка, а не два разных человека.

Итак, первая часть романа - примерно четверть - разворачивается в Амьене в 1910 году. Автор учудил что-то среднее между "Госпожой Бавари" Флобера и "Любовником леди Чаттерли" Лоуренса. Молодой англичанин - Стивен - приезжает во Францию по делам фирмы, останавливается в доме владельца текстильной фабрики, влюбляется в его жену Изабель, соблазняет её. Процесс соблазнения, собственно, был достаточно скоротечен, поскольку Изабель охотно откликнулась. Вообще, я пишу сейчас пост в состоянии некоторого разочарования автором. Слишком уж проста композиция. Центральная часть - война Стивена и Джека в 1916-1918 - написана превосходно. Но вот Амьен в 1910 и обстоятельства внучки Стивена в конце 1970-х - это, конечно, не было лишним, но мне было бы как-то привычнее воспринимать всё в мозаичной совокупности. Вот до чего меня постмодернисты довели - я уже не могу читать обычную прямую незатейливую прозу.

Непонятно, почему 20-летний пацан был отправлен в другую страну по достаточно серьезным финансовым делам. Создалось впечатление, что писатель просто не придумал ничего лучше.

При описании любовных сцен между Стивеном и Изабель автор использовал ишервудское "I am a camera", что выразилось в итоге в излишнем подчеркивании силы страсти. Когда достаточно неуклюже описывалось, как Стивен ласкает Изабель губами (короче, речь идет о куннилингусе) - это я еще мог принять. Неуклюжесть слов оправдывалась как бедностью интимного словаря в русском языке, так и неуклюжестью первых объятий влюбленных, на что, они, впрочем, не обращают внимания. Они не обращают, а я обратил, меня покоробило. В данном случае нужна не камера, а живопись. Ладно, описание орального секса от мужчины женщине в более изощренном и лиричном ключе уже встречалось мне, я призвал на помощь как это, так и свои представления. Но совсем "добила" сцена в которой Стивен кончает от ласк Изабель рукой, при этом автор решил дать героине инстинкт "не оставления следов", и последние капли Стивена Изабель принимает в рот. Смысл? Я отложил книгу на пару минут, сделал глубокий вздох, пошарил в голове, но ничего там не нашел этакого живописного, кроме порнографии.

Это было волнующе, всё же, и я продолжил читать.

Изабель и Стивен уехали. Изабель скрывает беременность. Изабель убегает из-за чувства вины. Это были такие явные клише, что я просто-таки вздохнул с облегчением, когда началась война, уж простите.

Идет война. Стивен - холодный и отчужденный человек - волей неволей сближается с товарищами по оружию, в частности с примечательным капитаном Уиром, который командует группой британских минеров. Они делают подкопы, роют туннели, чтобы заложить взрывчатку под позиции немцев. В туннелях происходит значительная часть действия. Туннели становятся важнейшим символом романа, даже важнее птиц, хотя автор, видимо, так не планировал. На первый план выходит другой главный герой - минер Джек. Тоже весьма сдержанный человек. Как и многие персонажи романа, Джек погибает. Несмотря на множество смертей, несмотря на мрак, та часть романа, где описывается война - самая ЧИТАЕМАЯ. Пока вокруг все умирают, я прощаю Стивену его неуклюжесть несколько лет назад. Боже, да это такая ерунда! Главное - вернись домой живым, солдат. Но этого мало. Оставь войну позади, забудь, стань снова собой. Ведь если ты этого не хотел - значит, этого не было.

Главное достижение автора - описание того, как люди подобно слепым кротам рыскали по туннелям в поисках друг друга, чтобы убить. Есть два пути - вперед и назад - и всё. Деться некуда, но пусть будут прокляты те люди, которые заварили эту кашу, а расхлёбывают простые парни, которые теряли любимых, теряли детей от болезней. Как будто этого мало...

Финальная по хронологии, но не композиции, часть романа, где описывается жизнь 38-летней внучки Стивена - бизнес-леди Элизабет - оставила меня равнодушным. Я не понял, зачем она вообще была нужна. Молодые люди, не знавшие ужасов обоих мировых войн, расшифровывают дневник Стивена. Это меняет что-то в них? Нет. Элизабет больше волнуют ее феминистские идеи. Хотя, отсутствие смысла - тоже смысл, хотя радости это и не доставило.

Возможно, мне стоит вернуться к практике, когда я писал посты спустя месяцы после чтения книги. Эта книга так меня взъерошила, что даже как-то трудно собраться с мыслями. Простите, что нет глубоких и умных сентенций.

Но это первое впечатление - тоже ценное. По крайней мере, такого давно уже не было.

Читать дальше

+5 мне нравится комментировать в избранное ссылка

# Рецензия на книгу «Миф о Сизифе»

romeo7 30 ноября 2014 г., 17:00

Все тлен. Так можно передать суть эссе Камю. Абсурд мира – это неспособность разума найти ответы на вопросы мироздания, это глухие стены нашего восприятия, за которыми прячется истина. Все наши иллюзии исчезают с возрастом, и приходит понимание, что познание мира настолько крохотное, а сама жизнь на фоне вселенной такая ничтожная, что возникает вопрос: для чего я живу? В чем смысл жизни? Откуда мы и куда идем? Такие вопросы задает каждый, но ни каждый способен видеть в глубину вещей и явлений.

Камю пишет, что к абсурдности мира приходят многие, которые не находят ответы на свои вопросы, видят смерти и пустоту, недовольны действительностью, проявляют бунт и требования к мирозданию. Я интуитивно чувствовал давно, что мир какой-то сюрреалистичный, напоминающий порой фильмы Дэвида Линча. Я часто пытался логически понять его и догадывался, что здесь пахнет каким-то абсурдом или просто я неспособный познать истины вселенной.

Многие сталкиваются с нищетой, болезнями, тяжелыми испытаниями, обращаются к Богу, но, естественно, не получают ответа. (Ответы от Бога Моисею, разговор с Ноем и прочие библейские мифы я не рассматриваю в контексте фактов, а лишь как мифы).

> Решить, стоит или не стоит жизнь того, чтобы ее прожить,- значит ответить на фундаментальный вопрос философии.

На этот вопрос искали ответы многие философы. Некоторых людей это приводит к самоубийствам. Ведь суицид кажется протестом против театра абсурда, смелым поступком, вызовом мирозданию, попыткой получить власть если не над своим рождением и жизнью, то хотя бы над смертью. Но Камю считает, что в театре абсурда жизни, уходить из этой жизни еще больший абсурд. Он считает, что абсурд – это проклятие человека и необходимое условия существования. Новое метафизическое осмысления своей жизни открывает человеку другие возможности. Да, эмпирическим путем познать мир практически невозможно. Но чем больше загадок, чем сложнее жизнь, тем можно проще жить, ничего себе не усложняя. Мы привыкли, что существует какой-то глубочайший смысл жизни, скрытый то ли в философских трудах, то ли в длительных многолетних медитациях, которые практикуют тибетские монахи. Но, на самом деле, каждый из нас жизни придает тот смысл, который посчитает нужным. И в этом свобода, выбрать свой путь и следовать ему. Конечно, найти смысл жизни бывает мучительно трудно, иногда возникает безнадега, но если верить в себя и заручаться поддержкой в близких, то все получится. И этот смысл, может быть не сакральным, а банальным: жить для себя и дать возможность жить другим.

Творчество Сартра, в частности роман «Тошнота» оказал большое значение на Камю. Абсурдность мира, бренность существования. Но Камю рассмотрел проблему глубже.

> Рано или поздно наступает время, когда нужно выбирать между созерцанием и действием. Это и называется: стать человеком. Мучения при этом ужасны, но для гордого сердцем нет середины. Либо бог, либо время, или крест, или меч. Либо мир наделен величайшим смыслом, бесконечно превосходящим все треволнения, либо в нем нет ничего, кроме треволнений. Нужно жить своим временем и умирать вместе с ним или же уклоняться от него во имя высшей жизни.

> Сам по себе этот мир неразумен — вот все, что можно сказать о нем. Абсурдно же столкновение этой иррациональности с отчаянной жаждой ясности, зов которой раздается в глубинах человеческой души.

> Наконец, я подхожу к смерти и тем чувствам, которые возникают у нас по ее поводу. О смерти все уже сказано, и приличия требуют сохранять здесь патетический тон. Но что удивительно: все живут так, словно “ничего не знают”. Дело в том, что у нас нет опыта смерти. Истинным, в полном смысле слова, является лишь то, что пережито, осознано. У нас есть опыт смерти других, но это всего лишь суррогат, он поверхностен и не слишком нас убеждает. Меланхолические условности неубедительны. Ужасает математика происходящего. Время страшит нас своей доказательностью, неумолимостью своих расчетов. На все прекрасные рассуждения о душе мы получали от него убедительные доказательства противоположного. В неподвижном теле, которое не отзывается даже на пощечину, души нет. Элементарность и определенность происходящего составляют содержание абсурдного чувства. В мертвенном свете рока становится очевидной бесполезность любых усилий. Перед лицом кровавой математики, задающей условия нашего существования, никакая мораль, никакие старания не оправданы a priori.

Мои выводы об эссе следующие.Нет научного доказательства Бога и загробной жизни. Возможно все наши надежды, мечты и сама жизнь исчезнет после смерти, а смерть просто, как вечный сон. Правда, я немного верю и надеюсь на посмертное существования для бессмертной души, но научной базы для этого нет. Но все равно имеет смысл жить здесь и сейчас. В ключевой момент сейчас важно, что ты чувствуешь и что делаешь в жизни. Если же есть высший разум и посмертное существование, то за все поступки хорошие и плохие будем держать ответ. Тогда актуальны такие понятия, как карма, реинкарнация и пр. Но даже, если всего этого нет, ключевым моментом в жизни является быть человеком мыслящим, стремится к познанию и совершению хороших поступков, путем проб и ошибок. Теперь я понимаю, почему многие верят в Бога. Ведь легче абсурдность мира, жесткокость и страдание списать на то, что "на все воля Бога" и перекласть ответственность за жизнь на плечи Всевишнего. Я, как агностик, это не поддерживаю. И вообще, я сам хочу написать эссе про суть жизни и про Бога, хотя и не являюсь философом. Это будет любительские эссе.

Жить максимально полно жизнью, творить добро другим людям, любить близких людей, стараться прощать врагов (хотя не всегда получается), изучать новые вещи, открывать мир, добиваться целей, даже если все тлен. В любом случае имеет смысл то, что происходит в жизни прямо сейчас. Ради вот таких моментов стоит жить. Не важно есть Бог или нету, есть ли загробный мир с раем и сотней девственниц (как кто-то писал подобное), или все это иллюзии. Но я считаю, что добрые поступки и стремление к познанию и самореализации уже делает чуточку этот мир добрее.

Свобода у нас есть: выбрать свой путь, свое призвание в жизни, окружить себя людьми, которые интересны, максимально полно стараться прожить день и меньше заморачиваться об абсурдности. Да, она есть, но ее понимание придает жизни еще больше ценности. Мы не свободны, когда родились и попали в этот мир, но мы свободны в том, что бы каждое мгновение делать свой выбор дальше.
Это эссе – великая вещь. Камю гениален. Столько мыслей в голове, столько идей после прочитанного. Буду перечитывать со временем Камю и знакомится с трудами других философов. Быть может, наша жизнь, как Сизиф труд, абсурдна, но, в то же время, наполнена смыслом в момент сейчас. Тогда многие вещи для нас откроются под другим неизведаннм углом. А что может быть совершенней, чем гармония в теперешнем времени, когда все остальное не имеет значение?

P.S. Теперь в очередной раз убедился, что философские труды в сотни раз важнее, чем художка, ибо дает столько пищи для ума, расширяет сознание, что изнутри прямо распирают мысли и желание прорабатывать метафизические аспекты бытья дальше.

Читать дальше

+11 мне нравится 2 комментария комментировать в избранное ссылка

# Рецензия на книгу «Камероны»

Masha_Uralskaya позавчера 15:21

В последнее время меня преследует тема британских шахтеров. Не так давно я посмотрела фильм о знаменитой забастовке 1984 года, теперь же, мне в руки попала книга, повествующая о самом начале зарождении борьбы рабочих за свои права. А учитывая то, что ранее эта тема была мне вовсе чужда, знакомство получилось крайне необычным и интересным.
Роман "Камероны" Роберт Крайтон писал, основываясь на истории своей собственной семьи. Возможно, именно благодаря шотландским корням и тому, что данная тема была ему особенно близка, он смог очень убедительно передать дух и атмосферу небольшого шахтерского поселка, и проблемы, которые занимали его жителей в конце 19 века.

История начинается в Питманго, но впервые по-настоящему мы видим этот поселок чуть позже, глазами человека, который привык смотреть на море, и никогда не видел, как добывают уголь. Черная-черная долина с черными-черными домами, в которых живут черные-черные люди - похоже на начало страшной сказки, но для углекопов это реальная жизнь.

Много часов проводя в забое, они пропитываются угольной пылью насквозь. Пыль окрашивает их с ног до головы и забивается в легкие, а глаза их поражает шахтерская слепота. Зарабатывают они, разумеется, гроши, но, в общем, не жалуются на свою судбу, привыкнув за сотни лет, что все идет своим чередом, так, как угодно богу и их всемогущему хозяину. К моменту описываемых событий, рабство в Шотландии было уже отменено, рабочие ежегодно праздновали День освобождения углекопа, но по-сути, особых изменений в их жизни не произошло. Судьбами каждого из них по-прежнему распоряжался лорд, а не закон. Лорд наказывал и награждал по своему милостивому усмотрению, и многие годы эта ситуация устраивала всех. До тех пор, пока в поселке не появились Камероны.

Поначалу Камеронов как таковых и не было. Была только Мэгги Драм, дочь шахтера, и внучка шахтера. Девушка из самой беднейшей и простой семьи Питманго, с самыми непростыми амбициями, твердо решившая изменить свою жизнь. Мэгги - движущая сила романа, без устали предпринимающая все возможное для того, чтобы выбиться в люди. Она нашла себе подходящего мужа и родила подходящих детей, она поставила себе цель и плевать хотела на мнение окружающих.
Именно благодаря Мэгги в поселке и появился Гиллон Камерон, обращающий на себя внимание огромным ростом и белой кожей, впервые спустившийся в угольную шахту, и оставшийся там на пару десятилетий. Гиллон и Мэгги стали прекрасной парой. Ее пробивной характер и его готовность подчиняться оказались идеальным сочетанием, в первую очередь для амбициозных планов Мэгги. И понадобится целых 20 лет, чтобы выяснить, что глава в этой семье, все-таки, мужчина.

Несмотря на то, что это, в первую очередь, социальный роман, начало его является, скорее, семейной сагой. Автор неторопливо описывает нам зарождение семьи, развитие отношений между супругами, рождение детей и процесс их взросления. Разные характеры каждого члена этого небольшого, но гордого клана, объединяет то, что каждый из них, благодаря наставлениям матери, чувствует себя Камероном, и с гордостью несет свое имя. В Питманго же их всех, даже родившихся и выросших в поселке, по-прежнему считают чужаками, их недолюбливают и им не доверяют. Но все меняется, когда в события вмешивается социальная составляющая. Революционные настроения, витающие в то время по всей Европе, удивительным образом добрались и до Питманго. Библиотекарь Селкёрк принес в этот консервативный край марксистские идеи, и исподволь подготовил почву для первых рабочих протестов. И вот, когда Гиллон Камерон начинает борьбу за то, что принадлежит ему по праву, в его поддержку выступает уже не только собственная семья, но и все те, кто раньше считал его чужаком.

Очень увлекательно и волнительно следить за этой маленькой, но, все же, революцией. За переворотом сознания, за изменением устоев, за сменой приоритетов. И за личной революцией Камеронов, в ходе которой каждый из них становится немного другим человеком. Эта крепкая семья с честью преодолевает все трудности и преграды, и становится лишь сильнее. Уж за них-то беспокоиться точно не приходится. Камероны всегда выкрутятся, можете о них не волноваться!

Читать дальше

+39 мне нравится 7 комментариев комментировать в избранное (1) ссылка

# Рецензия на книгу «Рыжий Орм»

Jasly 23 ноября 2014 г., 13:12

Когда я читал Бенгтссона, мне пришла на ум одна из моих любимых детских книжек: история Генри Хаггарда про Эрика Светлоокого. Помните, было такое издание крупного формата, в мягких обложках и трех частях? Я даже заехал к родителям, нашел эти книжки и забрал домой. Но в целом сравнить Бенгтссона мне не с чем, потому что ничего подобного мне в последнее время, кажется, не попадалось.

Однако для начала скажу, что меня основательно смутила аннотация тут, на ЛайвЛибе. Там сказано, что это пародия на классический викингский роман. Я, правда, не знаю, что такое «классический викингский роман», но сомневаюсь, что в 40-х годах уже существовала острая необходимость его пародировать. То же самое касается фразы: «выверенность исторического материала в сочетании с едкой иронией автора, который не упускает случая поиздеваться над викингами, их нравами и обычаями».

Безусловно, ирония и иногда некоторая насмешливость повествованию присущи, но никакого стремления «поиздеваться» над обычаями и нравами викингов я у Бенгтссона не заметил (и, простите, даже возьму на себя смелость заявить, что ничего подобного там нет).

Да, его герои, может быть, не всегда соответствуют современным представлениям о героике. Но, знаете, мы же в детстве тоже думали, что рыцари - это благородные ребята на коняшках, которые служат благоухающим дамам. Бенгтссон, мне кажется, и не ставил задачи показать идеального скандинава-викинга. Сам он в ответ на вопрос о творческих целях, которые преследовал этой книгой, заметил: «Я хотел рассказать историю, которую люди читали бы с удовольствием, как «Трех мушкетеров» или «Одиссею».

Впрочем, все вышесказанное не столь важно, сколь (skål!) важен тот факт, что это, по-моему, совершенно дивный и блистательный роман. Бенгтссон демонстрирует, как на достаточно, с современной точки зрения, тривиальном событийном материале (поплыли туда, сразились, поплыли сюда, сразились, построили дом, родили детей) выстроить текст, который будет как бы сам себя вам читать. Ну правда, полное ощущение, что вы идете под парусом и ветер все время попутный.

Я вычитал в вики, что в 1998 году на национальном телевидении Швеции провели зрительское голосование по поводу самых значительных шведских книг XX века. «Рыжий Орм» стал третьим, между прочим обойдя Сельму Лагерлеф и Астрид Линдгрен. Не фунт изюму.

Читать дальше

+28 мне нравится 1 комментарий комментировать в избранное (1) ссылка

# Рецензия на книгу «Мэри Энн»

Julia_cherry 6 декабря 2014 г., 15:34

Ну что же? Благодаря знакомству с Мэри Энн, моя коллекция героинь, идущих напролом в достижении поставленной цели пополнилась еще одним восхитительным персонажем. Разумеется, я не смогла полюбить её также безусловно, как в своё время Скарлетт (да-да, и не объясняйте мне, что Скарлетт - гадкая самолюбивая стерва, не поможет!), но своё место рядом с циничной умницей Ребеккой Шарп она, безусловно, заняла. Причем, если уж говорить о степени аморальности поведения, то это место даже повыше Бекки. Несмотря ни на что, Мери Энн все-таки отвечала за своих троих детей и была искренне привязана к брату, а это, несомненно, добавляет ей очков в моих глазах. К слову добавлю, что еще одна героиня, с которой я познакомилась этим летом, временами вспоминалась мне, пока я читала рассказ об авантюрах и повседневности Мери Энн Фаркуар Кларк - Конфетка!

Да-да, поскольку именно с Конфеткой они наиболее близки не только профессией, но и целеустремленностью, приземленностью, а также внутренней холодностью в сочетании с телесной искушенностью. Впрочем, роман Дафны дю Морье написан намного сильнее и гораздо менее провокативно (тут нет мата, грязи, физиологизма, а оказывается, о продажной любви можно и без этого!), чем упомянутое творение Фейбера, так что сравнение здесь только тематическое.
В те времена, о которых повествует книга, совсем другие авторы писали о женщинах, которые стремились отвечать за себя и своих близких, прежде всего детей, и тут на ум приходят "Незнакомка из Уайлдфелл-Холла" Энн Бронте, и некоторые истории Джейн Остин, и, конечно, известные "романы о гувернантках" сестер Бронте. Но, конечно, именно тогда жила знаменитая леди Гамильтон, да и вообще фаворитизм был в почете по обе стороны Ла-Манша. Так что такая героиня с сомнительными представлениями о морали вполне соответствует духу эпохи.
Героиня по-своему честна.

> – Благоденствие английской нации, будущее Англии… – Будущее Англии! Чепуха! Вы хотели сказать, мое будущее. Фунты стерлингов, шиллинги, пенсы, плюс премия для Мери Энн Кларк. Слава Богу, я не лицемерю, как большинство из вас. Я всегда знала, что мне нужно, и старалась это получить.

И она старается это получить. Она зарабатывает собой, цинично используя для этого все подвернувшиеся возможности. Да, она на три года становится фавориткой герцога Йоркского, но герцог не отличается щедростью, и она пытается выживать... Самое яркое и привлекательное в ней, это, конечно, искренняя привязанность сначала к отчиму, а затем - к брату и сыну. Привязанность не слепая - нет, Мери Энн трезво видит все слабости отчима, а затем и брата, - но привязанность безусловная. Еще в юности она поняла, что женщины всегда зависят от мужчин, а дети - от матери. И она печется о своих вырастающих мужчинах, без сентиментальности отдавая себя в руки тех, кто платит подороже...
В книге прекрасно прописаны второстепенные персонажи, а также сам дух времени. В неё умело и ненавязчиво вплетены элементы истории и политики, войн и интриг, сплетни о нравах ганноверской династии, которая занимала английский трон, подробности парламентских слушаний и даже отдельные проблемы управления богатыми домами вкупе с вопросами ведения домашнего хозяйства и умения жизни в кредит. Последнее меня всегда восхищало в романах Бальзака, где живущие за счет богатых женщин и их занятых мужей молодые красивые мужчины - отлично обходятся неимоверно туманными гарантиями при получении кредитов и прекрасно справляются со своей совестью отсутствием каких-либо моральных терзаний. Впрочем, и уже упомянутая выше Бекки Шарп Роден Кроули тоже долго легко вела хозяйство без копейки в кармане.
В общем, хотя своей упертостью героиня напоминает мне Скарлетт О'Хару, а в целом эта книга во многом близка "Ярмарке тщеславия" Теккерея, она не выглядит вторичной. Особое очарование роману придает тот факт, что он написан о реальном человеке, прабабушке Дафны дю Морье, а еще, разумеется, то, что героиня выполнила условие, поставленное герцогом. Она - не написала ни слова об истории их любовной связи. А вот в отношении своих потомков наша авантюристка такого обещания не подписывала. И кто тогда мог знать, что у циничной и легкомысленной Мэри Энн в двадцатом веке появится такой замечательный потомок, как талантливая писательница Дафна дю Морье, грани творчества которой я с удовольствием начала открывать для себя в этом году. И обязательно продолжу! И вам советую. :)

Читать дальше

+48 мне нравится 13 комментариев комментировать в избранное (4) ссылка

# Рецензия на книгу «Шаги по стеклу»

Deli 3 декабря 2014 г., 08:51

Если у вас паранойя, это еще не значит, что за вами не следят.
Бэнкс, я не знаю, что ты делаешь с мирозданием, но не останавливайся.

Книга просто взрывает представления о реальности - сложившиеся, устоявшиеся. Я бы даже сказала - настоявшиеся на затхлом аромате дынных корочек и рационального мышления. Я узнаю этот приём: три истории, казалось бы, такие разные, совсем друг с другом не связанные, существующие параллельно. История любви молодого художника, история нервного помешавшегося мужика, история фантастического замка и его узников. Однако нет-нет да и проскакивают намёки, нависает угроза тотальной связи всего со всем. Тянутся звенья, мелькают параллели. Когда начнёшь понимать все аллюзии, когда откроется в полной мере вся картина происходящего - вот тогда оно и ударит по тебе.
В головах людей есть некие сложившиеся шаблоны достоверности. Интуитивные догадки, что можно считать настоящим, а что нет. Весьма скучная и унылая картина мира, к счастью, размываемая литературой и другими происками воображения.

Так вот, Бэнкс ставит под вопрос это всё. Незыблемые представления о реальности разрушаются, всё становится иллюзорным, и уже невозможно понять, что существует, а что нет.

Те, кто знают, что такое теория игр, получат дополнительные клетки на доске. А те, кто не знают, прочитают это в послесловии. Не буду рассказывать, что конкретно в книге происходит, чтобы не испортить впечатление, но всё там творящееся - это чёртова головоломка, и читатель вовлечен в процесс не меньше персонажей. Персонажи очень странные, делают они странные вещи и в странных местах. А если места не являются странными сами по себе, то их такими делает искажённое восприятие. Всё становится запутанным, как гирлянда, но в том-то и дело, что ничего распутывать не хочется - оно прекрасно в том виде, в каком оно есть. Пока ничего не понятно, крышу сносит.
А еще не могу не отметить, что все три сюжетные линии прописаны совершенно по-разному и по-разному затягивают. Заслуга переводчика тоже огромна.
История про стеклянный замок шикарна, но история про сумасшедшего мужика во сто крат едрёней, так что она - мой фаворит х)

Читать дальше

+80 мне нравится 19 комментариев комментировать в избранное (1) ссылка

# Рецензия на книгу «Doctors Wear Scarlet»

astrojuggernaut 2 декабря 2014 г., 22:56

«Sorry no money, suggest eat baby», — телеграфировал как-то Саймон Рейвен жене (под baby подразумевая их общего ребенка), и некрологи писателя в унисон пересказывали эту историю — посмотрите, каким был редкостным шутником! Можно, конечно, поспорить насчет того, кем нужно быть, чтобы выстрелить такой шуткой; и, если на то пошло, Doctors Wear Scarlet — просто неправдоподобно мизогинный роман для жанра, в котором задавала тон Мина Харкер. Но это книга не столько женоненавистническая, сколько, гм, мужелюбивая — иерархия персонажей, если их расположить по убыванию достоинств, выглядит примерно так:

Талантливый и привлекательный протагонист;
сослуживец, готовый пожертвовать жизнью ради протагониста; нарратор, теоретически готовый пожертвовать жизнью ради протагониста;
друг, готовый пожертвовать ради протагониста своей гетеросексуальностью; полицейский, готовый ради всех упомянутых жертвовать своим временем (еще он читает Кавафиса);
суровые греки, готовые мокнуть под ливнем и жертвовать мулами, лишь бы все эти жертвенные англичане убрались с их острова;
...
проклятущая вампирша; невеста протагониста («cow-like»); секретарь профессора («a frightful slut»); жены, родственницы «and other female belongings» второстепенных героев, мулы, мебель, камни.

Засаживание кола (сорьки) — это вообще, при всех коннотациях, феерическая сцена.

Один с ужасом держит, второй с отвращением вбивает. Закрой глаза и думай об Англии. Шутки шутками, но роман совершенно заслуженно хвалят за развернутую метафору того, как Реальное вторгается в Символическое; как в кружок академиков, которым лишь раз в год позволено побеситься и погорланить срамные песенки (которые тоже регламентированы) вторгаются те сами древние божки, которыми они заняты в оставшиеся 364 дня в году. И в целом Doctors Wear Scarlet гораздо ироничнее прочих программных трактовок того, что «ну дык вампиры — это всегда о сексе». Меня угораздило когда-то посмотреть «Джонатана» Ганса Гайссендорфера (и N раз пересмотреть), после чего такой редукционизм, извините, не приемлю в принципе. Если уж упрощать до «А — это Б», то вампиры — это то, что ест того, кто думает о вампирах. Думаю, у Саймона Рейвена было предостаточно моделей: университетское и армейское начальство, многочисленные кредиторы, позже — издательства, которые, давая какие-никакие средства к существованию, умеют пить кровь как никто другой. А телеграмма, на которую Рейвен так хлестко ответил, гласила: «wife and baby starving».

Читать дальше

+28 мне нравится комментировать в избранное ссылка

# Рецензия на книгу «Полузабытая песня любви»

sivaja_cobyla 1 декабря 2014 г., 13:01

РОКОВЫЕ СТАРИКИ

Я с некоторой опаской бралась за новый роман Кэтрин Уэбб «Полузабытая песня любви». А все из-за того, что две предыдущих вещи автора очень уж мне понравились, скроены ладно и по-женски аккуратно с уважением к читательскому вниманию, все линии сюжета продуманы и доведены до логического конца, персонажи характерны и объемны. Но вот не было во мне веры, что автор сможет продержаться на прежнем уровне и третий роман. Бывают же осечки даже у великих, а уж у молодых и подавно все неровно. Забудутся, заиграются с успехом и состряпают что-то на волне читательского интереса, небрежно пользуясь приемами, уже принесшеми удачу. Ну, так вот с «прежним» уровнем я действительно ошиблась. Роман получился лучше предыдущих. Все, что радовало в двух первых опытах – осталось, но появилось и что-то новое, что я назвала бы уже авторской зрелостью, собственным стилем.

Не буду снова хвалить Уэбб за внимание к мелочам, логичность и продуманность сюжета, хороший язык (это еще респект переводчикам), все это уже пройденный этап и все это по-прежнему присуще автору. Коснусь того нового, что появилось в «Полузабытой песни любви».

Визитной карточкой Уэбб уже стали сюжеты, развивающиеся в двух временных пластах. В «Песне» это – наше время и тридцатые-сороковые годы прошлого века, период перед и в самом начале Второй Мировой. Далекие друг от друга годы словно бусины нанизаны на нитку истории жизни и смерти художника Чарльза Обри, чьим творчеством одержим герой в нашем времени, галерист и несостоявшийся художник Зак Гилкрист. Оставшись один на руинах распавшегося брака, скучающий по пятилетней дочке, он решает написать книгу о знаменитом рисовальщике и том времени, что художник провел в небольшой деревушке графства Дорсет, Блэкноуле. Когда-то в детстве Зак с семьей и сам там бывал, более того, в прошлом его бабушки есть белые пятна, связанные с ее давней поездкой в Блэкноул и встречей с Обри. Туманные намеки несчастной в семейной жизни женщины дают Заку повод думать, что он является потомком любимца женщин и ловеласа Чарльза Обри. И Зак решает отправиться в Блэкноул, причем не только за разгадкой тайны нескольких портретов неизвестного юноши кисти Обри, но и по следам собственных семейных секретов. Там он знакомится с местной отшельницей полуколдуньей-полусумасшедшей пожилой женщиной Димити (Мици) Хэтчер, той, что девочкой позировала Обри для нескольких картин блэкноулского периода творчества. Однако знакомство это лишь добавляет загадок в историю знаменитого живописца, поскольку Димити утверждает, что у них с Обри был прекрасный и пылкий роман, который закончился бы свадьбой, если бы не трагедия, случившаяся в семье художника много лет назад.

Собственно рассказы-воспоминания Димити и соединяют два временных слоя романа, разделенные семьюдесятью годами. Это и есть один из новых и очень удачных приемов, отличающих «Песню» от предыдущих двух романов Уэбб. Там повествования из разных времен просто перемежались между собой, разрывая ткань романа на фрагменты, здесь же рассказы о разных годах плавно перетекают друг в друга, не оставляя ощущение грубого шва или порожка, о который порой спотыкался читатель, например, в «Незримом», где линия прошлого была куда интереснее происходящего в настоящем. В «Песне» истории Зака и Димити так искусно переплетены, что создается ощущение единого временного полотна, где в настоящем присутствует прошлое. Возможно, это связано с тем, что для Димити прошлое настолько живо, что она становится тем живым мостиком, по которому события прошлого приходят в сегодняшний день, равноправно существуя в нем с событиями текущими. Постепенно и неторопливо перед Заком разворачивается история деревенской дикарки Мици, дочки блэкноулской знахарки и гетеры, совершившая крутой поворот, когда в деревню приехал красавец Чарльз Обри со своей любовницей-мароканкой Селестой и двумя дочерьми. С того момента жизнь Мици приобретает единственный смысл – любить и быть любимой недосягаемым кумиром, быть музой художника и не останавливаться ни перед чем на пути к его сердцу. И эта страсть становится единственным мотивом всех поступков Мици в прошлом и Димити – в настоящем, заставляя ее множить и множить тайны вокруг имени и судьбы Обри.

И еще один новый для Уэбб литературный прием, делающий «Песню» очень привлекательной для чтения, мне хочется сейчас отметить. Дело в том, что весь роман построен вокруг фигуры Чарльза Обри, но ему самому слово ни разу не предоставляется. О его творчестве мы узнаем от Зака, о его жизни и характере – из рассказов женщин, когда-то его окружавших и любивших. И при этом образ художника получился настолько реалистичным и выразительным, что иногда даже кажется, что это вполне реальный исторический персонаж, а не миф, созданный автором романа.

И вот еще о чем заставила меня задуматься «Песня» (а я очень люблю, когда чтение дает пищу для размышления). Подавляющее большинство героев романа к моменту начала повествования уже глубокие старики. Это и бабушка Зака, и Димити и другие обитатели Блэкноула. Но страсти и события, что управляли ими много лет назад, настолько живы в их душах, так ярко отразились в характерах, что невольно вспоминается чье-то высказывание: «Когда мне семьдесят, это значит, что мне одновременно и десять и сорок пять, и тридцать и девятнадцать. Я мальчишка и дед, юноша и зрелый мужчина, это все я и это все сейчас». Каждый человек несет в себе неповторимую историю и, может быть, если бы давали себе труд услышать эти истории даже от самых близких нам пожилых людей, мы бы почувствовали насколько они живы душой. И тогда бабушка, пекущая вкусные пирожки, возможно, останется в памяти внуков той роковой красавицей, которой они видели ее только на фотографиях, а вечно брюзжащий дед, даже летом одетый в теплую жилетку, станет настоящим героем и примером для подражания.

Я от всей души рекомендую «Полузабытую песню любви» для прочтения, и даже немного завидую тем, у кого оно впереди.

Читать дальше

+36 мне нравится 5 комментариев комментировать в избранное ссылка

# Обзор Алекса Бертрана Громова, посвященный ярмарке non/fictio№

samokat_book вчера 11:07

# Рецензия на книгу «Сон №9»

Wender 30 ноября 2014 г., 15:20

-Скажи, деревенский житель, чем лягушки отличаются от жаб? - спрашивает Бунтаро.
-Жабы живут вечно. Лягушки прыгают под колеса.
"Сон №9" Дэвид Митчелл

Митчелл великолепен. В каждой своей истории. В каждой книге. В каждом сне, бреде, потоке сознания, который он разворачивает перед тем, кто открывает его книгу.
С первых строк происходит мгновенное узнавание. Не думаю, что его вообще можно с кем-то перепутать.
Это ощущение поломанной реальности, попытки понять: где ты, все ещё в воспаленном воображении героя или уже на улицах реального Токио. И есть ли вообще хоть что-то реальное во всем происходящем.
От этого все попытки издателей сравнивать ЭТО с кем-то, навешивать ярлыки "нового Мураками" раздражают неимоверно. Это Дэвид Митчелл. Ему не надо быть кем-то ещё, чтобы его заметили и увидели.

И это тот самый автор, который к моменту написания number9dream уже создал потрясающего "Литературного призрака", а всего через несколько лет погрузит читателей в многоголосье "Облачного атласа".

Его легко узнать, но не стоит ожидать, что здесь вы увидите тоже самое.
Если основа призрака это мысль о том, что неважно где ты, важно, что ты никогда не будешь один. То сны раз за разом напоминают: ты один, но ты справишься.Вместо переплетения историй, связанных между собой тонкими невесомыми нитями перед читателем развернется история одного мальчика-парня-мужчины.
Именно так.

Попытка описать, о чем все это будет бессмыслена и обречена на провал.
Попытка описать, о чем все это может быть успешна благодаря паре предложений: молодой парень отправляется из провинции в огромный Токио, чтобы найти отца, которого он никогда не видел и о котором он ничего не знает. А любопытство всегда имеет цену.
Попытка понять, о чем все это по паре предложений выше так же глупа, как аннотации к книгам Митчелла.

А кроме этого это возможность почувствовать Токио. Возможно сквозь розовые очки влюбленного в него человека, но ведь легче всего влюбиться в какое-то место, когда его тебе показывает влюбленный в него человек. Да он не местный житель и не покажет тебе укромные уголки города, но даже по известным всем местам он проведет тебя такими дорогами, что захочется возвращаться снова и снова. "Когда-то давным-давно люди строили Токио. Но с тех пор что-то изменилось, пошло не так, и теперь Токио строит людей."
"Музыка. Ты питаешься ею, но и она питается тобой." Она тут только фон. Робкие звуки в телефонной трубке, единственный концерт, но она звучит и не хочет умирать. Значит ей, наверное, стоит быть.

И главный герой. Такой маленький и такой смелый.
На протяжении всех глав герой будет проваливаться в страннейшие сны, попадать в фантастические до абсурда ситуации в настоящем и взрослеть.
Каждый сон напоминает один из слоев кокона из которого на наших глазах выползает непонятная зверушка, которая с легкостью может оказаться и бабочкой, и молью. На свой лад они учат мечтателя Эйдзи Миякэ жестокости, выступая подготовкой к тому трэшу, который будет случаться с ним в реальности. И это тоже отличает эту книгу от других у автора.
Никогда не думала, что можно сплести вместе боулинг, якудзу, сделку, написанную кровью и получить такую, хм, картинку. Для меня, как для визуала, все это рисуется просто прекрасно и эмоциональная окраска этой сцены сопоставима с головой лошади в "Крестном отце" или сценами в ванной в "Ауте". От них перетряхивает, но выкинуть их из головы, потом будет сложновато. И тут я только надеюсь, что не один безумец не прочитает эту книгу, потому что будь я жаждущим крови мафиози, точно знаю, в какую игру сыграла бы я со следующим обидчиком.

Но кроме крови, ошметков мозгов, бега и погонь здесь так много грусти и тоски, что очень странно ощущение после последней страницы. Вместо того, чтобы прокручивать в голове ужас последних страниц; боль матери и сына, сгинувших в дебрях борделей; трагическую судьбу двойняшек; жалеть о бессмысленности смертей и восхищаться мужеством смертницы в борьбе с тайными ужасами города; вместо всего этого я улыбалась.
Улыбалась той вере и надежде, которую снова подарил мне этот британский гений.
Все шаги Эйдзи, все упорство и фанатичная преданность цели были не зря. Любой пройденный метр, даже если он пройден в неправильном направлении, нужен и важен. Он делает нас теми, кто мы есть. А как с этим жить нас не сможет научить ни одна книга и история в мире. Только помочь увидеть правильное направление и не пасть духом, когда очень хочется.
Спасибо Дэвиду Митчеллу за стертые в очередной раз границы реальности, за то, что сейчас вокруг все искрит от надежды и новых сил и за кислород, который он дает мне с каждой книгой.

Девятый сон начинается всякий раз, когда что-нибудь заканчивается.

Читать дальше

+42 мне нравится 4 комментария комментировать в избранное (3) ссылка

# Подборка книг «Лучшие книги 2014 года по версии Publishers Weekly»

Seterwind 6 декабря 2014 г., 06:06

Еще
81 книга

Лучшие книги 2014 года по версии американского журнала Publishers Weekly.
В подборке собраны книги в следующих категориях:

Top 10 (10 книг)
Fiction (20 книг)
Non-fiction (25 книг)
Mystery/Thriller (12 книг)
Young-adult (19 книг)
Romance (6 книг)
SF/Fantasy/Horror (7 книг)

Категории Poetry, Comics, Picture Books, Middle Grade, Religion и Lifestyle я проигнорировала. Полный список можно посмотреть по ссылке ниже.
Подборка в процессе наполнения

+28 мне нравится 86 книг 2 комментария комментировать в избранное (14) ссылка

# Рецензия на книгу «Побежденные»

Kisizer 30 ноября 2014 г., 13:13

Это одна из тех книг, которые не отпускают и спустя годы. Я читала ее, я жила в ней целую неделю, меня буквально трясло, когда я не могла взять книгу в руки. Я забросила интернет, хобби, домашние дела, фильмы по вечерам: как же можно заниматься другими делами, когда они там без меня, а вдруг что случится, а я пропущу это... Как будто где то там разворачивается параллельный мир, люди со строк книг в самом деле двигаются, думают, живут, влюбляются, говорят о России-по-настоящему! Все, что мне было интересно ранее, заменила эта история, ее герои. Финал меня опустошил.

Я долго думала, говорила об этом времени с мужем, перечитывала рецензии, написанные ранее-в чем то соглашалась, в чем то нет. Я была твердо уверена, что перечитывать книгу больше не смогу-слишком больно и безысходно. Но чем больше проходит времени от момента прочтения, тем чаще я думаю о героях, о судьбах их и отечества.

Это связано воедино и неизменно. Агония царской России. Ее величия, интеллекта, былой славы и доблести. И пусть моя рецензия будет длинной, но я выскажусь по этому поводу полностью.

Я никогда не скрывала своих политических взглядов, хоть и родилась в Советском Союзе. Почти на его осколках, конечно, но застала его былую славу, пионерию, нудные речи вождя на каком то съезде партии в черно-белом телевизоре, и не менее нудные их похороны с классической музыкой в этот день из каждого утюга. Во мне усиленно воспитывали дух патриотизма великому Ленину с помощью льстиво-приторных рассказиков о том, как маленький Вова Ульянов доедал кашу, сознавался в том, что разбил вазу и всегда поступал хорошо. Наверное в этот момент во мне уже зародилось отвращение к этому показушно- идеальному человеку. Став старше, начав читать и думать о судьбе нашей страны в контексте истории и революции, мне сразу стало очевидно, что идеальный путь развития России это был бы выход к Конституционной монархии. Власть монарха ограниченная Конституцией и Законодательными органами.

> «Нужен строй, при котором наш великий народ действительно получил бы возможность выправиться и расцвести и развить свои лучшие свойства. Погибнуть в боях, которые сметут с лица земли это подлое цека — на три четверти нерусское, — вот все, чего я хочу для себя, в этом все мое честолюбие! Вы знаете, там, в лагерях, мне мерещилось иногда всенародное ополчение, подобное Куликовской битве или Смутному времени, — могучая, светлая устремленность всего народа, решающая великая битва, хоругви, знамена, звуки «Спаси, Господи, люди твоя» и колокольный звон!»

Но у нас же все всегда проходит через одно место и никогда не без людских жертв. У России свой, особый путь и так было всегда.

> Святая! Любимая! Вечная! Какая нужна Тебе форма правления, какая? Либералы? Да им бы только чтоб все было как в Европе. Навпускают иноземцев, и те, как шакалы, бросятся расхватывать лакомые кусочки, они вернут Тебя к пределам времени Иоанна Грозного, наделают десятки русских республичек величиной со Швейцарию, чтобы удобнее было грабить. Исцели Свои раны силами Своего же народа, Сама, изнутри. И да не вступит никто, никто на Твою землю. Омой, очисти Себя Сама и роди нового Государя, Хозяина, любящего Тебя Господина!

Ну хорошо, примем как факт, без анализа первопричин (эта тема бесконечная и не относящаяся к книге) : настала революция, как мы ее помним из школьного курса истории "верхи не могут, низы не хотят". Царя убрали, уничтожили, чтобы никогда в дальнейшем никто из Романовых не мог претендовать на престол государства. К власти пришло временное правительство большевиков-"кухарка, дорвавшаяся до управления государством" (на чьи деньги и чьими силами было все организованно-тоже отдельный разговор). Из любой революции всегда,как следствие, вытекает гражданская война, и тут начинается самое страшное, не поддающееся никаким внутренним оправданиям и объяснениям: красный террор. Большевиков уничтожили как класс, обезоружили и положили на обе лопатки. Касалось бы: все, враг повержен, старый мир разрушен до основания, живи в новом мире и радуйся, строй светлое коммунистическое будущее, деля квартиры и имущество кулаков, но нет! Надо обязательно преследовать и добивать тех, кто хоть как то выделяется из общей массы нового советского народа,даже спустя десятилетие после революции.

> Я не удивлюсь, когда объявят военным преступником меня, и если в один прекрасный день военный трибунал вынесет смертный приговор князю Дашкову — активному белогвардейцу, — я найду его вполне заслуженным. Но, когда меня травят как Казаринова, который отбыл шесть с половиной лет лагеря за то только, что не выдал товарища, и когда я знаю, что в случае расправы со мной будут всячески преследовать и мучить до последнего вздоха мою жену и моего ребенка, — я не могу не думать, что ваш коммунизм — кровавое пятно в истории России. И вы уверяете при этом, что указываете путь к прогрессу и счастью, вы?!

То, что происходило в дальнейшем, можно назвать по настоящему страшными страницами Российской Истории. Не революция стала ими, отнюдь нет. Она свершилась быстро, стремительно, хоть и имела под собой многолетнюю подготовку, но все таки у нее не было столько жертв, как у дальнейшего красного сталинского террора. И самое ужасное было в том, что вся мощь агрессии властьимущих была направлена на собственный народ, не на иноязычного противника, которых пришел захватить земли, а на своих собственных людей, которые уже приняли новый строй, пытались приспособиться и выжить, на интеллигенцию и умнейших людей прошлого времени. Уничтожались, причем целенаправленно, под любым предлогом, врачи, ученые, изобретатели, писатели: все, что составляло бы в любом другом строе гордость и красу страны.

> Я понимаю, что в самом принципе аристократизма есть нечто возмутительное, несправедливое в самом корне: небольшая часть общества оттачивает, утончает и облагораживает свои чувства и свой мозг в то время, как вся масса поглощена борьбой за существование. Но ведь положение, при котором возможно было это различие, уже отмирало, дворянство разорялось, оно уже потеряло свои привилегии. Еще две-три либеральные реформы — и с этим порядком было бы навсегда покончено. А те реки крови, в которых вы пожелали утопить людей, вместо того чтобы разумно использовать их, привели только к тому, что вы истребили интеллигенцию, во всяком случае, потомственную, рафинированную. Попробуйте обойтись без нее! У вас уже теперь не хватает «кадров», а чем дальше, тем будет хуже. Вам грозит полный застой мысли. Культура воспитывается поколениями, вы разрушили то, что создавалось веками!

Поощрялись доносы, кляузничество, шпионаж даже в собственной квартире. Мало того, что этих людей обокрали до самого последнего, что у них было, у них пытались забрать даже честь, заставляя доносить на своих же домашних. Противное, унижающее обе стороны действие. При том, что во времена царской России это испокон веков считалось подлостью.

> Известен разговор Николая Первого с молодым Раевским. Император спросил: «И вы не сочли долгом сообщить мне?!» А тот ответил: «Такой поступок не вяжется с честью офицера, Ваше Величество!» И Николай пожал ему руку со словами: «Вы правы!»

А гонения на церковь? Веками люди верили в Бога, а тут пришла кучка людей и начала всем объяснять, что "Бога нет".

> Конечно, я всегда готова исполнить свой долг по отношению к каждому, но души моей пусть с меня не спрашивают. Я вольна вложить ее куда сама захочу. Если Господь Бог вернется в Россию, то воскреснет сестра милосердия, а сейчас я — медсестра, и пусть этого довольно будет тем, кто так исказил, заштемпелевал и прошнуровал нашу жизнь!

Конечно, людьми без веры в душе легче управлять. Они уже грех за грех не сочтут, их моральные качества станут пластичными и можно будет вылепить что угодно. Создавалась новая вера- Культ Личности, которой теперь следовало слепо поклоняться и принимать любое действие для блага народа. Но, к сожалению, любой человек смертен, а с ним смертна и вера в него. Жаль только что не все из гонимого поколения дожили до этого момента. Как говорил оппонент князя Дашкова:

> Не устрой мы красного террора — не устоять Советской власти.

Ладно, хватит о политике. Все равно у истории нет сослагательного наклонения. Страшное было время, страшные, трагические судьбы каждого, чье имя будет упомянуто в книге. Центральных действующих лиц здесь несколько-две семьи, связанные друг с другом причудливыми нитями, с их родственниками и знакомыми. Они держатся вместе, пытаясь устоять на ветру перемен, сберечь свою культуру, честь, любовь, право быть вместе, а порой и жизнь. В центре истории князь Дашков, белый офицер, раненый в Крыму, осужденный и отбывший наказание на каторге, пытающийся начать жизнь с чистого листа под другой фамилией. Почти нищий, часто болеющий, умнейший человек, но совершенно бесполезный со своими знаниями и уж тем более происхождением в этом новом мире. Его любимая Ася- талантливая пианистка, хрупкий и нежный цветочек, дочка своих родителей, рожденная для счастья, баловства, неги, оказавшаяся выброшенная в этот жестокий мир, где честной девушке, бывшей дворянке, везде вход заказан. В некоторых рецензиях ее осуждают за то, что она не смогла себя пересилить и с двумя голодными детьми пойти торговать на рынок мясом, а я почему то ее понимаю. Она как птенец, выброшенный из гнезда. В ней еще нет той защитной брони, которая позволила бы ей отгородиться от мира, очерстветь и сделать то, что ей надо. Даже если бы она пересилила себя и пошла, то представляю, как бы наторговала! Вообще все без исключения герои мне очень сильно напомнили потерпевших поражение южан из книги "Унесенные ветром". Люди, чей мир был снесен до основания, хватающиеся за осколки прошлого и испуганно озирающиеся по сторонам, даже не способные сопротивляться и перестраиваться под новые реалии. Ни одной Скарлетт на всю книгу. Даже благоразумная Ёлочка, чья судьба окажется более счастливой по сравнению со всеми остальными, все равно представитель того, уходящего поколения.

И все таки, двое героев из книги мне были наиболее симпатичны за цельность характера и свои убеждения. Мика и Мэри. Наиболее гармоничные и честные ребята. Знающие, чего хотят и идущие к своей цели несмотря ни на что. Пытающиеся сохранить Веру для будущих поколений, они становятся началом духовенства нашего настоящего. Для меня вопрос православия в каждой такой книге советского периода и про него очень важен. Я все время пытаюсь понять, за что России все это нужно было пережить и почему. И как жили священники и монахи все это гонимое время, откуда у них хватало сил верить и проповедовать, когда все было против, когда демоны владели Россией? Жить, вдали от всего, что любили, испытывая лишения и мучения, но все равно, не отрекаться и славить Господа, молится о спасении России.

> Великое это утешение — церковь Божия. Как войдешь в храм — ровно душ принял, только душ не для тела, а для духа нашего.

> Нам — христианам — дано великое счастье обновлять душу в Таинстве Причащения.

Книга очень многогранная. Помимо истории здесь очень много различных судеб. Не скажу, что каждая из ни вызывает симпатию. Очень много слабых духом людей, которые поступаются своими же ценностями, идут на предательство вольно или по глупости и наивности души. Много в ней антисемитизма, но я не могу за это осуждать героев, тем более сейчас, с высоты своего времени. В конце концов у каждого была своя правда и не доказано, что было иначе. Много в книге гордыни, подчеркнутого морального превосходства перед людьми, которые не дворянского происхождения, но и присутствует понимание того, что и среди простых людей есть честные и порядочные люди. В любом случае, книга очень сильная и цепляющая, дающая пищу для размышлений не только над судьбами и характерами людей в непростое время, но и всей России.

> Пожалуй, я даже не хотел бы реставрировать монархический строй. Я был связан с ним семейными традициями и привязанностями, но этих людей уже нет, а действительность показала, что эта форма правления уже отжила. Или пока неуместна. Я думаю теперь только о России.

Читать дальше

+42 мне нравится 26 комментариев комментировать в избранное (2) ссылка

# Рецензия на книгу «Агнес Грей»

elefant 29 ноября 2014 г., 23:45

Загадочная и в тоже время – совсем простая, привлекающая своей реалистичностью в изложении и душевной глубиной – такая была младшая из сестёр Бронте. Слава к ней пришла одновременно с сёстрами: в одном 1847 г. читатели увидели «Джейн Эйр», «Грозовой перевал» и «Агнес Грей», подписанные, как водится, анонимными авторами. В обществе поговаривали, что романы написаны одним и тем же автором – мужчиной, Энн и Шарлотте даже пришлось ехать в Лондон к критикам и убеждать их в обратном. Тогда-то и был развеян секрет, кто таится за именами Каррер, Эллис и Эктон Белл, хотя для простых читателей псевдонимы остались прежними.

Впрочем, затем про Энн Бронте позабыли, то ли вышедший на следующий год новый роман «Незнакомка из Уайлдфелл-Холла» была слишком шокирующий, то ли книг подобного жанра («книги о гувернантках») стало выходить предостаточно.

Так или иначе, но об авторах «Грозового перевала» и уж конечно же «Джейн Эйр» мы знаем сегодня гораздо больше, нежели об Энн Бронте. А между тем младшая из сестёр – пожалуй, наиболее интересная из них. Талант Энн Бронте, лишённый нервной, авангардистской «неровности» Эмили или изысканной, благородной «рационалистичности» Шарлотты, спокоен, внешне небросок – и обращён не столько вовне, сколько «внутрь себя». Все произведения Энн (их вышло всего два – думаю, было бы гораздо больше, не проживи она столь короткую жизнь) проникнуты душевной глубиной и переживаниями. Видимо потому, что источником к их написанию – послужила сама жизнь.

В основу первого произведения младшенькой Энн – «Агнес Грей» - легли реальные события, кроме того, роман во многом автобиографичен. Энн устами своей героини призналась, что основу книги составили дневниковые записки самой писательницы. Известно, что она постоянно вела свой дневник – практически до последних дней жизни. В этом первом литературном опыте начинающей писательницы отразились её переживания в то время, когда она была гувернанткой. Агнес Грей – это сама Энн Бронте. Энн, как и её героиня, вынуждена была поступить в гувернантки в очень раннем возрасте, и это было невыносимо для её духа. Ведь первые её подопечные были весьма избалованными и себялюбивыми особами (прямо как и у Агнес Грей). Жизнь в чужом доме у миссис Ингхэм среди незнакомых и глубоко чуждых Энн людей оказалась для неё невыносимой, отличавшейся к тому же крайней застенчивостью.

Энн была влюблена в священника, который поселился в её родном Хоуорте в 1840 г. Энн его горячо полюбила. В её жизни это была первая и единственная любовь, которая была взаимна. Уильям стал частым и желанным гостем в семье Бронте. Впрочем, этому чувству не суждено было завершиться счастливо – уже через два года знакомства молодой священник скоропостижно скончался. И звали его, кстати, практически как и героя романа – Уильям Уейтмэн. Его похоронили на церковном кладбище совсем рядом с домом Бронте. Энн сильно переживала и скорбила, чувства были настолько сильны, что Энн решила поведать о них всему свету. Конечно, читатель не простил бы своему автору подобной концовки, поэтому Энн Бронте его изменила. Между тем многое из написанного, хоть и изменено другими именами, имеет под собой реальную основу.

Энн в самом деле ничего не выдумывает, она пишет просто, очень реалистично, но при этом с неуловимым налётом романтичности, нежности, лиризма. Всё мы видим от лица главной героини, и пусть события, ею описываемые, просты и незамысловаты, этот роман читается легко и с неподдельным интересом. Современники указывали на тонкий юмор и мастерство изображения повседневной жизни викторианской Англии и передачи самых деликатных чувств, присущие роману "Агнес Грей" и по праву делающие его автора классиком мировой литературы. Впрочем, у всякой медли есть обратная сторона. Энн вкладывала в свои книги всю душу, переживала собственную историю вновь и вновь. Близкая подруга сестёр Бронте – Элизабет Гаскелл, в своей биографии «Шарлотты Бронте» вспоминала, как трагически это отражалось на здоровье младшенькой Энн. Сразу после выхода «Агнес Грей» её здоровье резко пошатнулось. К тому же прибавился семейный недуг – туберкулёз.

Несмотря на это, Энн задумала новый роман – о горькой судьбе женщин –«Незнакомка из Уайлдфелл-Холла». Шарлотта и Эмили всячески отговаривали сестру от идеи создания нового романа (злые языки сегодня утверждают – что они ей просто завидовали, ведь её книга сразу приобрела бешенную популярность, затмив «Джейн Эйр» и «Грозовой перевал»), впрочем – это далеко не так. Энн Бронте не отказалась от своего намерения и писала по нескольку страниц в день, постепенно заметно угасая. Уже в следующем 1848 году новый роман выходит в свет, немало возмутив чопорных англичан – ведь он посмел затронуть сами устои общества – вывел женщину из надлежащего ей уголка, сравняв с самими мужчинами.

Между тем, здоровье ещё более ухудшилось, и она отправилась на лечение в Скарборо. Там же в мае 1849 года она ушла из жизни. В возрасте всего 29 лет. Здесь же она была и похоронена – через полгода после смерти любимого брата Бернуэлла и сестры Эмили. Последние, как и мать Энн (впоследствии – и вся семья Бронте) и её любимый Уильям покоятся в родном Хоуорте. Поэтому, как ни печально, но Энн до сих пор суждено быть вдали от дома и своих близких и горячо любимых её людей.

Читать дальше

+37 мне нравится 5 комментариев комментировать в избранное (3) ссылка

# Рецензия на книгу «Letters from Father Christmas»

Faery_Trickster 25 ноября 2014 г., 15:06

Эта книга – одна из тех, для которых нужно выбрать правильное время. Декабрь-январь – самое идеальное, на мой взгляд, если только новогоднее настроение у вас не начинается ещё в июле. В любом случае, если вы почувствуете, что вас тянет к рождественской музыке или просмотру «Одного дома», можете смело браться за «Письма Рождественского Деда», будь то в английском или русском варианте, потому что столько тепла и новогоднего света нет, пожалуй, ни в одной книжке. Возможно, потому, что это вовсе не книжка?

История этих писем началась почти сто лет назад, в далёком 1920-м году, когда Джон, трёхлетний сын Толкиена, получил первое послание от Николаса Рождественского. С тех пор каждый год на протяжении 22 лет Толкиен писал своим детям волшебные новогодние истории, рассказываемые от имени милого старичка Николаса, Полярного Медведя или эльфа-секретаря.

Ни переезд, ни война не смогли нарушить эту традицию до тех самых пор пока Присцилла, последний ребёнок семьи Толкиенов, не стала старше своего «stocking age», то есть пока она не достигла того возраста, когда ребёнок считается выросшим и не получает подарков от Деда Мороза.

Сам тот факт, что Толкиен эти письма никогда не планировал издавать, делает их особенными. Они написаны не из желания прославиться, не из желания получить какую-либо материальную выгоду, даже не ради того, чтобы носить гордое звание «писатель», они написаны просто потому, что этого требовала его любовь к детям. Поэтому, читая «Письма», чувствуешь себя так, будто с тобой поделились частью собственной души.

Если вы любите другие работы Толкиена, «Письма» заставят вас любить его ещё больше. Если же прежде он вас не впечатлил, возможно, этими письмами ему удастся вызвать в вашем сердце тёплое отношение к себе. Важно помнить только одно: это не книга, это маленький фрагмент детства тех, кому повезло родиться в семье сказочника.

Первые письма, написанные Толкиеном, довольно короткие и цель их – просто пожелать детям хорошего праздника. Но чем дальше, тем больше подробностей из жизни Николаса мы узнаём. Сперва в его историях появляется Полярный Медведь, который, хоть и является незаменимым помощником, слишком неуклюж, потому часто становится причиной различных происшествий, разбавляя размеренную жизнь на Северном Полюсе забавными событиями. После мы узнаём о коварстве гоблинов, которые много лет тайно таскали из кладовых подарки, о войне с ними и прочих неприятностях.

Несмотря на то, что порой Толкиен в письмах говорит о таких серьёзных вещах, как бедность, голод, война, ни одно из них не является мрачным или печальным. Все они оставляют чувство тепла и надежды на то, что всё будет хорошо. Именно то, что всем нам так нужно в Новый год и Рождество.

Очень часто после прочтения детских книг начинаешь задумываться, что не так-то плохо было бы завести собственных детей, чтобы после читать полюбившиеся детские истории с ними. Примерно такие же эмоции вызывают и «Письма Рождественского Деда». Только не читать их хочется, а подарить однажды и своим детям такую же сказку, которую более 20 лет Джону, Майклу, Кристоферу и Присцилле дарил их отец, Джон Рональд Руэл Толкиен.

Читать дальше

+71 мне нравится 2 комментария комментировать в избранное (2) ссылка

# Рецензия на книгу «На маяк»

Kate_Lindstrom 27 ноября 2014 г., 15:51

Если бы я познакомилась с Вирджинией Вулф... мы бы друг друга поняли.
Но она далеко от меня - за гранитной плитой книжного переплета. Каждый сам за себя, и некому задать вопрос.
Она нанизывает реальность, как стеклянные бусинки на детское ожерелье. Воздушно-манящая, неприступно холодная, болезненно красивая.

Увидев друг друга, мы бы вынесли две не пересекающихся линии. Допустим, шел бы дождь. Я вижу женщину с печатью отчаянной грусти на лице, с острым, уверенным профилем. Идет дождь. Вот и все, что мне под силу сказать.
Она бы увидела мерцание мириад капель, превращенных по прихоти ветра в маленькие, игрушечные торнадо, которые никому не навредят, а впрочем, это как посмотреть. И молодую женщину, у глаз которой каскадами льется вода, рисует вихри, смешные маленькие вихри, но та женщина их почему-то не замечает. Возможно, она думает о грозе.

А возможно, ей сейчас припоминается давно упрятанное в мешок ненужного во взрослой жизни воспоминание о том, как будучи девочкой, она промокла насквозь июльским ливнем. И что-то блеснет в ее лице, когда она пройдет мимо.

В Вирджинии - громадная сила, которую она сама в себе не может объяснить, как не сможет и всякий читатель. Мне стоило больших трудов пропускать через себя ее всестороннесть, обычные слова в ее устах превращались в загадки сфинксов, в расплывчатые силуэты на картинах Моне. Мы по разные стороны баррикад: она созидает, а я, блеклая тень, так же точно пытаюсь анализировать.
Это попытка анализировать воздух. Но нет, она не пуста, вовсе не в этом смысле. Ею дышишь, настолько она целостна.
От нее перенимаешь почти невыносимую для плеч тяжесть - чувстововать все, не фильтруя. Честно скажу вам, в мои грани восприятия не укладывается, как можно жить, позволяя всем мыслимым микро и макрокосмам вливаться в недра сознания.

На той стороне она опять мучительно отбрасывает перо. Я, здесь, сейчас, в попытках сделать ее понятной для себя - тоже перо отбрасываю. (Фигурально, конечно. Могу отбросить клавиатуру, что будет эффектно, но непрактично.)
Если бы не леса условностей, если бы не моря десятков лет меж нами. Уверена, она была примечательным собеседником, но увы, на ее паутинных монологах лежит печать безмолвия.

У меня столько вопросов к ней... но мы никогда не встретимся. Поэтому я складываю оружие и остаюсь как есть: вопрошающая, покоренная, смотрящая на профиль писательницы, за которой мне не угнаться.

> То, что чувствуешь, - невозможно словами сказать.

***
Луч срезал с крыши солнце, поблескивал утомленный дождь. Почему-то Петербург. Тротуары проплывают людьми. И вдруг - она. Вот что будет сниться мне, когда я захочу узнать ответы на свои вопросы.

Читать дальше

+38 мне нравится 14 комментариев комментировать в избранное (2) ссылка
Страницы: предыдущая следующая
1 2 3 4 5 ...
Официальное приложение LiveLib для Андроида
play.google.com
Официальное приложение LiveLib для iOS
itunes.apple.com

### Самые активные читатели

индекс активности
sola-menta | 3902
nad1204 | 2249
deeplook | 2044
sher2408 | 1943
panda007 | 1895
girl_on_fire | 1874
TibetanFox | 1829
LeRoRiYa | 1814
Shishkodryomov | 1804
nezabudochka | 1801

### Ближайшие мероприятия

«Проект "Киносреда". Наше новое кино»

«Музыкальный вечер "А музыка звучит..."»

«Открытие фотовыставки из цикла «Траектория спорта»»

«Открытые уроки латиноамериканских танцев Free Dance»

«Церемония вручения литературной премии «Золотая тыква - 2014»»

«Праздничная предновогодняя встреча Бамbook`а»

«Творческая встреча с писателем Виктором Коняевым. Презентация книги «Непогасимая лучинка»»

«"Волгоградский читательский клуб" - XXXII Встреча»

«Открытые уроки латиноамериканских танцев Free Dance»

«"Музыка в библиотеке"»

### Свежие рецензии

«Убийственно просто»
Tunduk

«Сладкий папочка»
AnnaKornelia

«Германские элитные войска»
Narvik1940

«Степные боги. Разгуляевка»
satanakoga

«Первый закон. Книга 1. Кровь и железо»
sher2408

«Синяя Борода»
secret6

«Волшебная гондола»
AnnaKornelia

«Убийство в "Восточном экспрессе"»
Vanadis

«Дикая охота короля Стаха»
Spade

«Искупление»
satanakoga

### Новые истории

«Кафка на пляже»
951033

...
red_duke

Как не запутаться в переводах
olgadrozdenko

«А. Чехов. Собрание сочинений в восьми томах. Том 1»
AlenaRomanova

«Гарри Поттер и философский камень»
Fraken

Под впечатлением
Wise_owl

«Сладкое зло»
kate_kassie

Книжкина больничка
red_star

Обретение дома.
Godefrua

Перевод детской литературы
Jasly

### Обсуждения на форуме

Книгомарафон (Декабрь. 2014)
sunflower10

"Новая Рулетка". Третий тур 2014 года. Прием отчетов
sandy_martin

Игра в классики. Тур № 3. Прием заявок и отчетов.
orangekyo

Книгочейское мероприятие "Пятилетку - в три тома!". Первый тур. Прием заявок.
orangekyo

"Вокруг Света с Эркюлем Пуаро". Тур №2
Vanadis

"Билет в Историю" Тур №1. Прием заявок ЗАКРЫТ!
Spade

Исправить (дополнить) описание книг
Elmira730

КНИЖНЫЙ МАРАФОН!
silkwaxwing

Игра: почти как в "слова"
silkwaxwing

Спаси книгу - напиши рецензию! Тур №29
tatianadik

### Статьи в блогах

Новинки военно-исторической литературы и не только
"Люфтваффе над Поволжьем" от Дмитрия Дегтева и Дмитрия Зубова

Новости
Декабрьский анонс от «Рипол Классик». Часть 2

Партнеры
Международная ярмарка интеллектуальной литературы non/fictio№: между вечным и актуальным (обзор Алекса Бертрана Громова)

Новости
Журнал «Иностранная литература» — 2015

Клубный дом LiveLib
Зима в Белгородском КК «Бамbook»

Новинки военно-исторической литературы и не только
"Окопная правда" Вермахта" от Артёма Драбкин

Клубный дом LiveLib
Живое интервью с russischergeist: Азартный перфекционист

Блог LiveLib
Ноябрь на LiveLib. Все самое интересное

Партнеры
Книги в подарок от «Центрполиграфа»!

Блог LiveLib
Лайвлиб идет в массы!

### Этими книгами
часто интересуются

Пятьдесят оттенков серого

Мародер

Щегол

Виновата ложь

Мне тебя обещали

Идет загрузка...